from setuptools import setup, find_packages

setup(
    name="mcp-config",
    version="0.1.2",
    packages=find_packages(),
    install_requires=[
        "click>=8.0.0",
        "requests>=2.25.0",
    ],
    entry_points={
        "console_scripts": [
            "mcp-config=mcp_config.cli:main",
        ],
    },
    scripts=['bin/mcp-config'],
    author="David Schwartz",
    description="MCP Client Configuration Tool",
    python_requires=">=3.6",
)
